#ifndef INCLUDED_GSM_RECEIVER_CF_H
#define INCLUDED_GSM_RECEIVER_CF_H

#include <vector>
#include <list>
#include <gr_block.h>
#include <gr_complex.h>
#include <gr_feval.h>

#include <string>//!!
#include <map>//!!

class ccr_receiver_cf;

typedef boost::shared_ptr<ccr_receiver_cf> ccr_receiver_cf_sptr;
typedef std::vector<gr_complex> vector_complex;

ccr_receiver_cf_sptr ccr_make_receiver_cf();

/** GSM Receiver GNU Radio block
 *
 * GSM Receiver class supports frequency correction, synchronisation and
 * MLSE (Maximum Likelihood Sequence Estimation) estimation of synchronisation
 * bursts and normal bursts.
 * \ingroup block
 */

class ccr_receiver_cf : public gr_block
{
  private:

    friend ccr_receiver_cf_sptr ccr_make_receiver_cf();
    ccr_receiver_cf();

  public:
    ~ccr_receiver_cf();
    void forecast(int noutput_items, gr_vector_int &ninput_items_required);
    int general_work(int noutput_items,
                     gr_vector_int &ninput_items,
                     gr_vector_const_void_star &input_items,
                     gr_vector_void_star &output_items);
};

#endif /* INCLUDED_GSM_RECEIVER_CF_H */
